# Contributing to The Optimizer

Thank you for considering contributing to The Optimizer.

## How to Contribute

If you want to contribute to The Optimizer, please follow these steps:

1. Fork the repository on GitHub.

1. Create a new branch for your feature or bug fix:

   ```bash
   git checkout -b your-feature-name
   ```
   Consider naming your branch `feature/your-feature-name`, `fix/your-fix-name`, or similar, to make it more descriptive.
1. Make your changes, ensuring that your code is well-documented.
1. Commit your changes with a clear and descriptive commit message.
   
    Consider following a style-guide for commit messages, such as https://gist.github.com/robertpainsi/b632364184e70900af4ab688decf6f53

1. Push your changes to your forked repository.
1. Open a pull request (PR) to the main branch of the original repository.
   
   When opening a PR request be explicit in it's purpose, how you approached the problem and how your solution solves it. 
   If the PR is solving an open Issue, remember to link it by using the proper [keywords](https://docs.github.com/en/issues/tracking-your-work-with-issues/linking-a-pull-request-to-an-issue). 

## Reporting Issues
If you encounter any bugs, issues, or have suggestions for improvements, please feel free to open an issue in the  repository.

## License
By contributing to The Optimizer, you agree that your contributions will be licensed under the same [MPL 2.0 License](LICENSE) as the project.